embassy-stm32

Crates

git

Versions

stm32f446ve

Flavors

StopMode

Enum StopMode 

pub enum StopMode {
    Stop1,
    Stop2,
    Standby,
}
Specifies a limit for the stop mode of the peripheral or the stop mode to be entered. E.g. if StopMode::Stop1 is selected, the peripheral prevents the chip from entering Stop1 mode.

Variants



Stop1

Peripheral prevents chip from entering Stop1 or executor will enter Stop1



Stop2

Peripheral prevents chip from entering Stop2 or executor will enter Stop2



Standby

Peripheral does not prevent chip from entering Stop

Implementations

Source

impl StopMode

pub const fn at_least(&self, other: StopMode) -> bool

Return whether this stop mode is at least another stop mode.